@@ -3,7 +3,7 @@ import os
 import secrets
 import traceback
 import uuid
-from pathlib import Path
+# from pathlib import Path
 from urllib.parse import quote
 
 import dateutil.parser
@@ -30,22 +30,26 @@ class ConfigFlag(object, metaclass=Singleton):
     def __init__(self):
         self.stated = True
         self.config = False
+        logging.info('ConfigFlag constructor')
+
+
+CF = ConfigFlag()
 
 
 class Config(object, metaclass=Singleton):
     def __init__(self, config_path=None, config_dict=None):
-        if not ConfigFlag.config:
+        if not CF.config:
             self.loaded = False
             if config_path in [None, '']:
                 config_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'conf', 'config.yml')
             self.config_path = config_path
-            Path(self.config_path).mkdir(parents=True, exist_ok=True)
+            # Path(self.config_path).mkdir(parents=True, exist_ok=True)
             if config_dict is None:
                 logging.warning('Input configuration is empty')
                 self.config = {}
             self.config_input = config_dict
             self.init()
-            ConfigFlag.config = True
+            CF.config = True
             logging.info('Config initialized')
         else:
             logging.info('Config is already initialized')
